"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestSessionManager = void 0;
const utils_1 = require("./utils");
class TestSessionManager {
    constructor() {
        this.sessionsMap = new Map();
    }
    add(session) {
        this.sessionsMap.set(session.id, session);
    }
    update(session) {
        if (!this.sessionsMap.has(session.id)) {
            throw new Error(`Unknown session: ${session.id}`);
        }
        this.sessionsMap.set(session.id, session);
    }
    get(id) {
        return this.sessionsMap.get(id);
    }
    all() {
        return this.sessionsMap.values();
    }
    filtered(filter) {
        return utils_1.filtered(this.all(), filter);
    }
    forStatus(...statuses) {
        return this.filtered((s) => statuses.includes(s.status));
    }
    forTestFile(...testFiles) {
        return this.filtered((s) => testFiles.includes(s.testFile));
    }
    forBrowser(...browserNames) {
        return this.filtered((s) => browserNames.includes(s.browserName));
    }
    passed() {
        return this.filtered((s) => { var _a; return (_a = s.result) === null || _a === void 0 ? void 0 : _a.passed; });
    }
    failed() {
        return this.filtered((s) => { var _a; return !((_a = s.result) === null || _a === void 0 ? void 0 : _a.passed); });
    }
}
exports.TestSessionManager = TestSessionManager;
//# sourceMappingURL=TestSessionManager.js.map