#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_line_args_1 = __importDefault(require("command-line-args"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const runTests_1 = require("./runTests");
const puppeteer_launcher_1 = require("../implementations/browser-launchers/puppeteer-launcher");
const es_dev_server_1 = require("../implementations/servers/es-dev-server");
const commandLineOptions = [
    {
        name: 'files',
        type: String,
        multiple: true,
        defaultOption: true,
    },
    {
        name: 'watch',
        type: Boolean,
    },
    {
        name: 'coverage',
        type: Boolean,
    },
    {
        name: 'concurrency',
        type: Boolean,
    },
    {
        name: 'config',
        type: String,
    },
    {
        name: 'test-isolation',
        type: Boolean,
    },
];
const defaultCoverageConfig = {
    exclude: ['**/node_modules/**/*'],
};
(async () => {
    const args = command_line_args_1.default(commandLineOptions);
    let userConfig = {};
    const configPath = path_1.default.resolve(args.config || './web-test-runner.config.js');
    if (fs_1.default.existsSync(configPath)) {
        const module = await Promise.resolve().then(() => __importStar(require(configPath)));
        if (!module.default) {
            throw new Error('Config should have a default export');
        }
        userConfig = module.default;
    }
    const config = Object.assign({ files: [], watch: false, testFrameworkImport: 'web-test-runner/dist/implementations/frameworks/mocha.js', address: 'http://localhost', port: 9542, concurrency: 10, sessionStartTimeout: 10000, sessionFinishTimeout: 10000, browsers: puppeteer_launcher_1.puppeteerLauncher(), server: es_dev_server_1.createEsDevServer() }, userConfig);
    if ('files' in args) {
        config.files = args.files;
    }
    if ('watch' in args) {
        config.watch = !!args.watch;
    }
    if (args.coverage) {
        config.coverage = defaultCoverageConfig;
    }
    if ('concurrency' in args) {
        config.concurrency = args.concurrency;
    }
    if (!config.files) {
        throw new Error('You need to specify which tests to run.');
    }
    runTests_1.runTests(config);
})();
//# sourceMappingURL=cli.js.map