"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestReporter = void 0;
const getTestProgressReport_1 = require("./getTestProgressReport");
const getTestFileReport_1 = require("./getTestFileReport");
const getTestCoverageReport_1 = require("./getTestCoverageReport");
const TestSessionStatus_1 = require("../TestSessionStatus");
class TestReporter {
    constructor(terminal, sessions) {
        this.terminal = terminal;
        this.sessions = sessions;
        this.reportedFilesByTestRun = new Map();
    }
    reportTestRunStart(testRun, testFiles, allBrowserNames, favoriteBrowser, serverAddress) {
        if (testRun !== 0) {
            // Restart terminal
            this.terminal.restart();
        }
        // Log results of test files that are not being re-run
        for (const testFile of testFiles) {
            this.reportTestFileResults(testRun, testFile, allBrowserNames, favoriteBrowser, serverAddress);
        }
    }
    reportTestCoverage(coverageData, passedCoverage, coverageThreshold) {
        this.terminal.logStatic(getTestCoverageReport_1.getTestCoverageReport(coverageData, passedCoverage, coverageThreshold));
    }
    reportTestFileResults(testRun, testFile, allBrowserNames, favoriteBrowser, serverAddress) {
        const sessionsForTestFile = Array.from(this.sessions.forTestFile(testFile));
        const allFinished = sessionsForTestFile.every((s) => s.status === TestSessionStatus_1.STATUS_FINISHED);
        if (!allFinished) {
            return;
        }
        let reportedFiles = this.reportedFilesByTestRun.get(testRun);
        if (!reportedFiles) {
            reportedFiles = new Set();
            this.reportedFilesByTestRun.set(testRun, reportedFiles);
        }
        if (!(reportedFiles === null || reportedFiles === void 0 ? void 0 : reportedFiles.has(testFile))) {
            reportedFiles.add(testFile);
            this.terminal.logStatic(getTestFileReport_1.getTestFileReport(testFile, allBrowserNames, favoriteBrowser, serverAddress, sessionsForTestFile));
        }
    }
    reportTestProgress(config, args) {
        const dynamicEntries = getTestProgressReport_1.getTestProgressReport(config, args);
        dynamicEntries.push(`\nPress D to debug in the browser.`);
        this.terminal.logDynamic(dynamicEntries);
    }
    reportEnd() {
        this.terminal.stop();
    }
}
exports.TestReporter = TestReporter;
//# sourceMappingURL=TestReporter.js.map