"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBrowserLogsReport = void 0;
const chalk_1 = __importDefault(require("chalk"));
function getBrowserLogsReport(sessions) {
    const entries = [];
    const commonLogs = [];
    const logsByBrowser = new Map();
    const allLogs = sessions.map((s) => s.result.logs);
    for (const session of sessions) {
        for (const log of session.result.logs) {
            // for the first session, we always include all logs
            // for others we deduplicate logs, this way we can allow the same log
            // msg appearing multiple times while also deduplicating common logs
            // between browsers
            if (session === sessions[0] || !commonLogs.includes(log)) {
                if (allLogs.every((logs) => logs.includes(log))) {
                    commonLogs.push(log);
                }
                else {
                    let logsForBrowser = logsByBrowser.get(session.browserName);
                    if (!logsForBrowser) {
                        logsForBrowser = [];
                        logsByBrowser.set(session.browserName, logsForBrowser);
                    }
                    logsForBrowser.push(log);
                }
            }
        }
    }
    if (commonLogs.length > 0) {
        entries.push({ text: `🚧 Browser logs:`, indent: 1 });
        for (const log of commonLogs) {
            entries.push({ text: `${chalk_1.default.bold(chalk_1.default.gray('>'))} ${log}`, indent: 4 });
        }
    }
    for (const [browser, logs] of logsByBrowser) {
        entries.push({ text: `🚧 Browser logs on ${browser}:`, indent: 1 });
        for (const log of logs) {
            entries.push({ text: `${chalk_1.default.bold(chalk_1.default.gray('>'))} ${log}`, indent: 4 });
        }
    }
    if (entries.length > 0) {
        entries.push('');
    }
    return entries;
}
exports.getBrowserLogsReport = getBrowserLogsReport;
//# sourceMappingURL=getBrowserLogsReport.js.map