"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFileErrorsReport = void 0;
const utils_1 = require("./utils");
function getFileErrorsReport(testFile, allBrowserNames, favoriteBrowser, serverAddress, failedSessions) {
    var _a;
    const entries = [];
    const sessionsThatFailedToImport = failedSessions.filter((s) => s.result.failedImports.some((imp) => imp.file === testFile));
    if (sessionsThatFailedToImport.length > 0) {
        const session = sessionsThatFailedToImport.find((s) => s.browserName === favoriteBrowser) ||
            sessionsThatFailedToImport[0];
        const failedImport = session.result.failedImports.find((i) => i.file === testFile);
        const failedBrowsers = sessionsThatFailedToImport.map((s) => s.browserName);
        const failedOn = utils_1.createFailedOnBrowsers(allBrowserNames, failedBrowsers);
        entries.push({ text: `❌ Failed to run test file${failedOn}`, indent: 1 });
        entries.push({ text: utils_1.renderError(failedImport.error, serverAddress), indent: 6 });
    }
    const testErrorsPerBrowser = new Map();
    for (const session of failedSessions) {
        for (const test of session.result.tests) {
            if (test.error) {
                let testErrorsForBrowser = testErrorsPerBrowser.get(test.name);
                if (!testErrorsForBrowser) {
                    testErrorsForBrowser = new Map();
                    testErrorsPerBrowser.set(test.name, testErrorsForBrowser);
                }
                testErrorsForBrowser.set(session.browserName, test.error);
            }
        }
    }
    if (testErrorsPerBrowser.size > 0) {
        for (const [name, errorsForBrowser] of testErrorsPerBrowser) {
            const failedBrowsers = Array.from(errorsForBrowser.keys());
            const favoriteError = (_a = errorsForBrowser.get(favoriteBrowser)) !== null && _a !== void 0 ? _a : errorsForBrowser.get(failedBrowsers[0]);
            const failedOn = utils_1.createFailedOnBrowsers(allBrowserNames, failedBrowsers);
            entries.push({ text: `❌ ${name}${failedOn}`, indent: 1 });
            entries.push({ text: utils_1.renderError(favoriteError, serverAddress), indent: 6 });
            entries.push('');
        }
    }
    return entries;
}
exports.getFileErrorsReport = getFileErrorsReport;
//# sourceMappingURL=getFileErrorsReport.js.map