"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRequest404sReport = void 0;
const chalk_1 = __importDefault(require("chalk"));
function getRequest404sReport(sessions) {
    const entries = [];
    const common404s = [];
    const request404sPerBrowser = new Map();
    const all404s = sessions.map((s) => s.result.request404s);
    for (const session of sessions) {
        for (const request404 of session.result.request404s) {
            // for the first session, we always include all request 404s
            // for others we deduplicate 404s, this way we can allow the same 404
            // msg appearing multiple times while also deduplicating common 404s
            // between browsers
            if (session === sessions[0] || !common404s.includes(request404)) {
                if (all404s.every((r404s) => r404s.has(request404))) {
                    common404s.push(request404);
                }
                else {
                    let request404sForBrowser = request404sPerBrowser.get(session.browserName);
                    if (!request404sForBrowser) {
                        request404sForBrowser = [];
                        request404sPerBrowser.set(session.browserName, request404sForBrowser);
                    }
                    request404sForBrowser.push(request404);
                }
            }
        }
    }
    if (common404s.length > 0) {
        entries.push({ text: '🚧 404 network requests:', indent: 1 });
        for (const request404 of common404s) {
            entries.push({ text: `${chalk_1.default.bold(chalk_1.default.gray('-'))} ${request404}`, indent: 4 });
        }
    }
    for (const [browser, request404s] of request404sPerBrowser) {
        entries.push({ text: `🚧 404 network requests on ${browser}:`, indent: 2 });
        for (const request404 of request404s) {
            entries.push({ text: `${chalk_1.default.bold(chalk_1.default.gray('-'))} ${request404}`, indent: 4 });
        }
    }
    if (entries.length > 0) {
        entries.push('');
    }
    return entries;
}
exports.getRequest404sReport = getRequest404sReport;
//# sourceMappingURL=getRequest404sReport.js.map