"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSessionErrorsReport = void 0;
const utils_1 = require("./utils");
function isSameError(a, b) {
    return a.message === b.message && a.stack === b.stack;
}
function getSessionErrorsReport(sessions, serverAddress) {
    const entries = [];
    const sessionsWithError = sessions.filter((s) => { var _a; return !!((_a = s.result) === null || _a === void 0 ? void 0 : _a.error); });
    if (sessionsWithError.length === 0) {
        return entries;
    }
    const allSameError = sessionsWithError.every((e) => isSameError(e.result.error, sessionsWithError[0].result.error));
    if (allSameError) {
        const browserNames = sessions.map((s) => s.browserName);
        const failedBrowserNames = sessionsWithError.map((s) => s.browserName);
        entries.push({
            text: `❌ Failed to run test file${utils_1.createFailedOnBrowsers(browserNames, failedBrowserNames, false)}:`,
            indent: 1,
        });
        entries.push({
            text: utils_1.renderError(sessionsWithError[0].result.error, serverAddress),
            indent: 6,
        });
        entries.push('');
        return entries;
    }
    // only some browsers have an error, or each browser has a different error
    for (const session of sessionsWithError) {
        entries.push({
            text: `❌ Failed to run test file ${session.browserName}:`,
            indent: 1,
        });
        entries.push({
            text: utils_1.renderError(session.result.error, serverAddress),
            indent: 6,
        });
        entries.push('');
    }
    return entries;
}
exports.getSessionErrorsReport = getSessionErrorsReport;
//# sourceMappingURL=getSessionErrorsReport.js.map