"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTestFileReport = void 0;
const getFileErrorsReport_1 = require("./getFileErrorsReport");
const getBrowserLogsReport_1 = require("./getBrowserLogsReport");
const getRequest404sReport_1 = require("./getRequest404sReport");
const chalk_1 = __importDefault(require("chalk"));
const getSessionErrorsReport_1 = require("./getSessionErrorsReport");
function getTestFileReport(testFile, allBrowserNames, favoriteBrowser, serverAddress, sessionsForTestFile) {
    const failedSessions = sessionsForTestFile.filter((s) => !s.result.passed);
    const entries = [];
    entries.push(...getBrowserLogsReport_1.getBrowserLogsReport(sessionsForTestFile));
    entries.push(...getRequest404sReport_1.getRequest404sReport(sessionsForTestFile));
    entries.push(...getSessionErrorsReport_1.getSessionErrorsReport(sessionsForTestFile, serverAddress));
    if (failedSessions.length > 0) {
        entries.push(...getFileErrorsReport_1.getFileErrorsReport(testFile, allBrowserNames, favoriteBrowser, serverAddress, failedSessions));
    }
    if (entries.length > 0) {
        entries.unshift('');
        entries.unshift(`${chalk_1.default.bold(chalk_1.default.cyanBright(testFile))}:`);
    }
    // trim off a trailing empty line used for padding between errors
    if (entries[entries.length - 1] === '') {
        entries.splice(entries.length - 1);
    }
    return entries;
}
exports.getTestFileReport = getTestFileReport;
//# sourceMappingURL=getTestFileReport.js.map