"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTests = void 0;
const globby_1 = __importDefault(require("globby"));
const TestRunner_1 = require("./TestRunner");
const dedupeArray = (arr) => [...new Set(arr)];
async function collectTestFiles(patterns) {
    const testFiles = [];
    for (const pattern of Array.isArray(patterns) ? patterns : [patterns]) {
        testFiles.push(...(await globby_1.default(pattern)));
    }
    return dedupeArray(testFiles).map((f) => f);
}
async function runTests(config) {
    const testFiles = await collectTestFiles(config.files);
    if (testFiles.length === 0) {
        console.error(`Could not find any files with pattern(s): ${config.files}`);
        process.exit(1);
    }
    const testRunner = new TestRunner_1.TestRunner(config, testFiles);
    function stop() {
        testRunner.stop();
    }
    ['exit', 'SIGINT'].forEach((event) => {
        process.on(event, stop);
    });
    process.on('uncaughtException', (error) => {
        /* eslint-disable-next-line no-console */
        console.error(error);
        stop();
    });
    testRunner.start();
}
exports.runTests = runTests;
//# sourceMappingURL=runTests.js.map