"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.browserstackLauncher = void 0;
//@ts-ignore
const browserstack_local_1 = __importDefault(require("browserstack-local"));
const selenium_webdriver_1 = __importDefault(require("selenium-webdriver"));
const util_1 = require("util");
const constants_1 = require("../../core/constants");
function createBrowserName(userAgent) {
    const { browserName, device, browser_version = 'latest', os, os_version } = userAgent;
    return `${browserName !== null && browserName !== void 0 ? browserName : device}${browser_version ? ' ' + browser_version : ''} (${os} ${os_version})`;
}
function browserstackLauncher(args) {
    const username = process.env.BROWSER_STACK_USERNAME || process.env.BROWSERSTACK_USERNAME;
    const password = process.env.BROWSER_STACK_ACCESS_KEY || process.env.BROWSERSTACK_ACCESS_KEY;
    if (!username) {
        throw new Error('Missing BROWSER_STACK_USERNAME environment variable.');
    }
    if (!password) {
        throw new Error('Missing BROWSER_STACK_ACCESS_KEY environment variable.');
    }
    const { userAgents, buildName, project } = args;
    const drivers = new Map();
    let config;
    let serverAddress;
    let bsLocal;
    return {
        async start(_config) {
            config = _config;
            serverAddress = `${config.address}:${config.port}/`;
            bsLocal = new browserstack_local_1.default.Local();
            const bsLocalArgs = {
                key: password,
                force: true,
            };
            await util_1.promisify(bsLocal.start).bind(bsLocal)(bsLocalArgs);
            for (const userAgent of userAgents) {
                const capabilities = Object.assign({ timeout: 300, name: 'web-test-runner test', 'browserstack.user': username, 'browserstack.key': password, 'browserstack.local': true, project, build: process.env.BUILD_NUMBER ||
                        process.env.BUILD_TAG ||
                        process.env.CI_BUILD_NUMBER ||
                        process.env.CI_BUILD_TAG ||
                        process.env.TRAVIS_BUILD_NUMBER ||
                        process.env.CIRCLE_BUILD_NUM ||
                        process.env.DRONE_BUILD_NUMBER ||
                        buildName, video: true }, userAgent);
                const driver = new selenium_webdriver_1.default.Builder()
                    .usingServer('http://hub.browserstack.com/wd/hub')
                    .withCapabilities(capabilities)
                    .build();
                drivers.set(createBrowserName(userAgent), driver);
            }
            return Array.from(drivers.keys());
        },
        openDebugPage() {
            throw new Error('Not supported');
        },
        async stop() {
            process.kill(bsLocal.pid);
            await Promise.all(Array.from(drivers.values()).map((driver) => driver.quit().catch(() => { })));
            // TODO: kill selenium
            // for (const workerId of workerIds) {
            //   await promisify(client.terminateWorker).bind(client)(workerId);
            // }
            await util_1.promisify(bsLocal.stop).bind(bsLocal);
        },
        async startSession(session) {
            const driver = drivers.get(session.browserName);
            if (!driver) {
                throw new Error(`Unknown browser ${session.browserName}`);
            }
            driver.executeScript(`window.open('${serverAddress}?${constants_1.PARAM_SESSION_ID}=${session.id}')`);
        },
        stopSession(session) {
            // TODO: Find the right browser tab and close it
        },
    };
}
exports.browserstackLauncher = browserstackLauncher;
//# sourceMappingURL=browserstack-launcher.js.map